%define anolis_release 1
%global libver       1.2.2

Name:           libbpf
Version:        %{libver}
Release:        %{anolis_release}%{?dist}
Summary:        Libbpf library

License:        LGPLv2 or BSD
URL:            https://github.com/%{name}/%{name}
Source:         https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz
BuildRequires:  gcc elfutils-libelf-devel elfutils-devel
BuildRequires: make

# This package supersedes %{name} from kernel-tools,
# which has default Epoch: 0. By having Epoch: > 0
# this %{name} will take over smoothly
Epoch:          2

%description

libbpf is a library that provides a convenient and efficient way to interact 
with the Linux kernel's BPF subsystem. BPF stands for Berkeley Packet Filter, 
but it has evolved into a powerful framework for creating and running programs 
in the kernel. libbpf allows users to load and attach BPF programs to various 
hooks, such as network interfaces, tracepoints, kprobes, and more. It also 
provides APIs for manipulating BPF maps, which are key-value data structures 
that can be shared between user space and kernel space. libbpf is designed to 
be portable across different versions of the Linux kernel and compatible with 
the BPF CO-RE (Compile Once - Run Everywhere) feature.

This package is a mirror of bpf-next linux tree bpf-next/tools/lib/bpf 
directory plus its supporting header files. The version of the package reflects 
the version of ABI.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = 2:%{version}-%{release}
Requires:       kernel-headers >= 5.10.0
Requires:       zlib

%description devel
libbpf-devel is a development package for libbpf, a library that provides an 
interface to load and interact with BPF programs. BPF (Berkeley Packet Filter) 
is a technology that allows users to run custom code in the kernel without 
modifying it. libbpf-devel contains the header files and static libraries 
needed to compile and link applications that use libbpf. It also includes 
documentation and examples of how to use libbpf for various purposes, such as 
tracing, networking, security, and performance optimization.

%package static
Summary: Static library for %{name} development
Requires: %{name}-devel = %{epoch}:%{version}-%{release}

%description static
The %{name}-static package contains static library for
developing applications that use %{name}

%define _lto_cflags %{nil}
%undefine _package_note_file

%global make_flags \
    LIBDIR=/%{_libdir} NO_PKG_CONFIG=1 \
    LDFLAGS="%{build_ldflags} -Wl,--no-as-needed" \
    CFLAGS="%{build_cflags} -fPIC" \
    OBJDIR=%{_builddir} \
    DESTDIR=%{buildroot}

%prep
%autosetup -n %{name}-%{version}

%build
%make_build -C ./src %{make_flags}

%install
%make_install -C ./src %{make_flags}

%generate_compatibility_deps

%files
%dir %{abidir}
%{_libdir}/%{name}.so.%{libver}
%{_libdir}/%{name}.so.1
%{abidir}/%{name}.dump

%files devel
%{_libdir}/%{name}.so
%{_includedir}/bpf/
%{_libdir}/pkgconfig/%{name}.pc

%files static
%{_libdir}/%{name}.a

%changelog
* Wed Feb 28 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.2.2-1
- update to 1.2.2

* Thu Apr 13 2023 Zhongling <zhonglingh@linux.alibaba.com> - 1.1.0-2
- Refactor rpm spec

* Wed Feb 15 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.7.0-3
- downgrade to 0.7.0 to compat with kernel-5.10/kernel-5.19

* Tue Dec 13 2022 Kun(llfl) <llfl@linux.alibaba.com> - 1.1.0-1
- update version to v1.1.0
- optimise spec file

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.7.0-2
- optimise spec file

* Wed Mar 09 2022 Renbo <rb01097748@alibaba-inc.com> - 0.7.0-1
- Init for Anolis OS 23
